@@ -249,7 +249,7 @@ void LdapConfigWidget::Private::initWidget()
 
     if (mFeatures & W_SECBOX) {
         QGroupBox *btgroup = new QGroupBox(i18n("Security"), mParent);
-        QHBoxLayout *hbox = new QHBoxLayout;
+        auto *hbox = new QHBoxLayout;
         btgroup->setLayout(hbox);
         mSecNo = new QRadioButton(i18nc("@option:radio set no security", "No"), btgroup);
         mSecNo->setObjectName(QStringLiteral("kcfg_ldapnosec"));
@@ -279,9 +279,9 @@ void LdapConfigWidget::Private::initWidget()
     if (mFeatures & W_AUTHBOX) {
         QGroupBox *authbox
             = new QGroupBox(i18n("Authentication"), mParent);
-        QVBoxLayout *vbox = new QVBoxLayout;
+        auto *vbox = new QVBoxLayout;
         authbox->setLayout(vbox);
-        QHBoxLayout *hbox = new QHBoxLayout;
+        auto *hbox = new QHBoxLayout;
         vbox->addLayout(hbox);
 
         mAnonymous
